==> wildfly-dist-9.0.0.Final-src.zip: wildfly-9.0.0.Final-src/clustering/server/src/main/java/org/wildfly/clustering/server/GroupServiceNameProvider.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.server;

import org.jboss.msc.service.ServiceName;
import org.wildfly.clustering.service.ServiceNameProvider;
import org.wildfly.clustering.spi.GroupServiceNameFactory;

/**
 * Provides a service name for a group-based service.
 * @author Paul Ferraro
 */
public class GroupServiceNameProvider implements ServiceNameProvider {

    protected final String group;
    private final GroupServiceNameFactory factory;

    public GroupServiceNameProvider(GroupServiceNameFactory factory, String group) {
        this.factory = factory;
        this.group = group;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public ServiceName getServiceName() {
        return this.factory.getServiceName(this.group);
    }
}

==> wildfly-dist-10.1.0.Final-src.zip: wildfly-10.1.0.Final-src/clustering/server/src/main/java/org/wildfly/clustering/server/GroupServiceNameProvider.java <==
/*
 * JBoss, Home of Professional Open Source.
 * Copyright 2014, Red Hat, Inc., and individual contributors
 * as indicated by the @author tags. See the copyright.txt file in the
 * distribution for a full listing of individual contributors.
 *
 * This is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as
 * published by the Free Software Foundation; either version 2.1 of
 * the License, or (at your option) any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this software; if not, write to the Free
 * Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
 * 02110-1301 USA, or see the FSF site: http://www.fsf.org.
 */

package org.wildfly.clustering.server;

import org.jboss.msc.service.ServiceName;
import org.wildfly.clustering.service.GroupServiceNameFactory;
import org.wildfly.clustering.service.ServiceNameProvider;

/**
 * Provides a service name for a group-based service.
 * @author Paul Ferraro
 */
public class GroupServiceNameProvider implements ServiceNameProvider {

    protected final String group;
    private final GroupServiceNameFactory factory;

    public GroupServiceNameProvider(GroupServiceNameFactory factory, String group) {
        this.factory = factory;
        this.group = group;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public ServiceName getServiceName() {
        return this.factory.getServiceName(this.group);
    }
}
